==> nimbus-sample-1.0.4.zip: nimbus-sample/semaphore/ex1/Main.java <==

import jp.ossc.nimbus.core.ServiceManagerFactory;
import jp.ossc.nimbus.service.semaphore.Semaphore;

/**
 * TvPsNXB
 */
public class Main{
    
    public static final void main(String[] args){
        
        // T[rX`t@C[h
        if(ServiceManagerFactory.loadManager("service-definition.xml")){
            System.out.println("T[rX`̓ǂݍ݂ɐ܂B");
            
            // T[rX擾
            final Semaphore semaphore = (Semaphore)ServiceManagerFactory
                .getServiceObject("Semaphore");
            
            // \[X̎cmF
            System.out.println("c胊\[X : " + semaphore.getResourceRemain());
            
            // Z}tHl
            for(int i = 1; i <= 3; i++){
                System.out.print("Z}tHl[" + i + "]...");
                long start = System.currentTimeMillis();
                if(semaphore.getResource(500l)){
                    long end = System.currentTimeMillis();
                    System.out.println(" " + (end - start) + "[ms]");
                    System.out.println("c胊\[X : " + semaphore.getResourceRemain());
                }else{
                    long end = System.currentTimeMillis();
                    System.out.println("s " + (end - start) + "[ms]");
                }
            }
            
            System.out.println();
            
            // Z}tHJ
            for(int i = 1; i <= 2; i++){
                System.out.print("Z}tHJ[" + i + "]");
                semaphore.freeResource();
                System.out.println("c胊\[X : " + semaphore.getResourceRemain());
            }
            
            System.out.println();
            
            // Z}tHlXbh쐬
            Runnable getterRunnable = new Runnable(){
                public void run(){
                    System.out.println(Thread.currentThread().getName() + " : Z}tHl...");
                    if(semaphore.getResource()){
                        System.out.println(Thread.currentThread().getName() + " : ");
                    }else{
                        System.out.println(Thread.currentThread().getName() + " : s");
                    }
                }
            };
            
            // Z}tHl
            for(int i = 1; i <= 4; i++){
                Thread thread = new Thread(getterRunnable);
                thread.start();
            }
            try{
                Thread.sleep(1000);
            }catch(InterruptedException e){
            }
            
            // Z}tHl҂mF
            System.out.println("Z}tHl҂ : " + semaphore.getWaitingCount());
            
            // Z}tHl҂w肵āAZ}tHl
            // ҂w肵ȏ̏ꍇAlɎs
            System.out.print("Z}tHl҂2w肵ăZ}tHl...");
            if(semaphore.getResource(2)){
                System.out.println("");
            }else{
                System.out.println("s");
            }
            
            System.out.println();
            
            // Z}tHl҂J
            System.out.println("Z}tHl҂J");
            semaphore.release();
            
        }else{
            System.out.println("T[rX`̓ǂݍ݂Ɏs܂B");
        }
        
        // T[rX`t@CA[h
        ServiceManagerFactory.unloadManager("service-definition.xml");
    }
    
}

==> nimbus-sample-1.1.3.zip: nimbus-sample/semaphore/ex1/Main.java <==

import jp.ossc.nimbus.core.ServiceManagerFactory;
import jp.ossc.nimbus.service.semaphore.Semaphore;

/**
 * TvPsNXB
 */
public class Main{
    
    public static final void main(String[] args){
        
        // T[rX`t@C[h
        if(ServiceManagerFactory.loadManager("service-definition.xml")){
            System.out.println("T[rX`̓ǂݍ݂ɐ܂B");
            
            // T[rX擾
            final Semaphore semaphore = (Semaphore)ServiceManagerFactory
                .getServiceObject("Semaphore");
            
            // \[X̎cmF
            System.out.println("c胊\[X : " + semaphore.getResourceRemain());
            
            // Z}tHl
            for(int i = 1; i <= 3; i++){
                System.out.print("Z}tHl[" + i + "]...");
                long start = System.currentTimeMillis();
                if(semaphore.getResource(500l)){
                    long end = System.currentTimeMillis();
                    System.out.println(" " + (end - start) + "[ms]");
                    System.out.println("c胊\[X : " + semaphore.getResourceRemain());
                }else{
                    long end = System.currentTimeMillis();
                    System.out.println("s " + (end - start) + "[ms]");
                }
            }
            
            System.out.println();
            
            // Z}tHJ
            for(int i = 1; i <= 2; i++){
                System.out.print("Z}tHJ[" + i + "] ");
                semaphore.freeResource();
                System.out.println("c胊\[X : " + semaphore.getResourceRemain());
            }
            
            System.out.println();
            
            // Z}tHlXbh쐬
            Runnable getterRunnable = new Runnable(){
                public void run(){
                    System.out.println(Thread.currentThread().getName() + " : Z}tHl...");
                    if(semaphore.getResource()){
                        System.out.println(Thread.currentThread().getName() + " : ");
                    }else{
                        System.out.println(Thread.currentThread().getName() + " : s");
                    }
                }
            };
            
            // Z}tHl
            for(int i = 1; i <= 4; i++){
                Thread thread = new Thread(getterRunnable);
                thread.start();
            }
            try{
                Thread.sleep(1000);
            }catch(InterruptedException e){
            }
            
            // Z}tHl҂mF
            System.out.println("Z}tHl҂ : " + semaphore.getWaitingCount());
            
            // Z}tHl҂w肵āAZ}tHl
            // ҂w肵ȏ̏ꍇAlɎs
            System.out.print("Z}tHl҂2w肵ăZ}tHl...");
            if(semaphore.getResource(2)){
                System.out.println("");
            }else{
                System.out.println("s");
            }
            
            // Z}tHl҂ĊJ
            System.out.println("Z}tH҂~");
            semaphore.release();
            try{
                Thread.sleep(1000);
            }catch(InterruptedException e){
            }
            System.out.println("Z}tH҂Jn");
            semaphore.accept();
            
            // Z}tHl㋭JԂw肵āAZ}tHl
            // Z}tHl㎞Ԃw肵Ԃ𒴂ƁAIɊJ
            System.out.print("Z}tHl㋭JԂ1bw肵ăZ}tHl...");
            Thread thread = new Thread(getterRunnable);
            thread.start();
            if(semaphore.getResource(-1, -1, 1000)){
                System.out.println("");
            }else{
                System.out.println("s");
            }
            
            try{
                Thread.sleep(500);
                System.out.println("0.5b c胊\[X : " + semaphore.getResourceRemain());
                Thread.sleep(500);
                System.out.println("1.0b c胊\[X : " + semaphore.getResourceRemain());
            }catch(InterruptedException e){
            }
            
            System.out.println();
            
            // Z}tHl҂J
            System.out.println("Z}tHl҂J");
            semaphore.release();
            
        }else{
            System.out.println("T[rX`̓ǂݍ݂Ɏs܂B");
        }
        
        // T[rX`t@CA[h
        ServiceManagerFactory.unloadManager("service-definition.xml");
    }
    
}
